"""Run main module entry point (start background worker)."""
from feltoken.algorithm.train import main

if __name__ == "__main__":
    main()
